/******************************************************************************
 *                                                                            *
 * File:   nbcheck.c          Version  2.02            Date: 2010-04-03       *
 *                                                                            *
 * Copyright (C) 1998-2010 by Kostis Netzwerkberatung                         *
 * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056                        *
 * kosta@kostis.net (Konstantinos Kostis), http://www.kostis.net/             *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2010-04-03: KK V2.02                                                   *
 *        - see netbios.h                                                     *
 *                                                                            *
 *****************************************************************************/

#include <string.h>

#include "netbios.h"

/******************************************************************************

	Function:
		check NetBIOS name character

	Parameter:
		int		ch

	Returns:
		NBCHK_OK		if character is valid
		NBCHK_NAME_INVALID	if character is invalid

 *****************************************************************************/

static	int	CheckNBChar
(
	int		ch
)
{
	if (strchr (NCB_VALID_CHARS, ch) == (char *) NULL)
		return (NBCHK_NAME_INVALID) ;

	return (NBCHK_OK) ;
}

/******************************************************************************

	Function:
		check NetBIOS name

	Parameter:
		char		*NBName

	Returns:
		NBCHK_OK		if name is valid
		NBCHK_NAME_TOOLONG	if name is too long
		NBCHK_NAME_INVALID	if name contains illegal characters

	Sideeffect:
		converts content of NBName to UPPER CASE

 *****************************************************************************/

int	CheckNBName
(
	char		*NBName
)
{
	/**********************************************************************

		check max. length first

	 *********************************************************************/

	if (strlen (NBName) >= NCBNAMSZ)
		return (NBCHK_NAME_TOOLONG) ;

	/**********************************************************************

		make sure it's all UPPER CASE

	 *********************************************************************/

	strupr (NBName) ;

	/**********************************************************************

		are they all valid NetBIOS name characters?

	 *********************************************************************/

	while (*NBName != '\0')
	{
		if (CheckNBChar ((int) *NBName) != NBCHK_OK)
			return (NBCHK_NAME_INVALID) ;
		++NBName ;
	}

	return (NBCHK_OK) ;
}
