/******************************************************************************
 *                                                                            *
 * File:   nbclear.c          Version  2.02            Date: 2010-04-03       *
 *                                                                            *
 * Copyright (C) 1998-2010 by Kostis Netzwerkberatung                         *
 * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056                        *
 * kosta@kostis.net (Konstantinos Kostis), http://www.kostis.net/             *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2010-04-03: KK V2.02                                                   *
 *        - see netbios.h                                                     *
 *                                                                            *
 *****************************************************************************/

#include "netbios.h"

/******************************************************************************

	Function:
		Initialize NCB Data Structure

	Parameters:
		PNCB		pncb

	Returns:
		nothing

 *****************************************************************************/

void	ClearNCB
(
	PNCB		pncb
)
{
	int		i ;
	int		sncb_reserve = sizeof (pncb -> ncb_reserve) ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pncb -> ncb_command	= 0 ;
	pncb -> ncb_retcode	= 0 ;
	pncb -> ncb_lsn		= 0 ;
	pncb -> ncb_num		= 0 ;
	pncb -> ncb_buffer	= 0 ;
	pncb -> ncb_length	= 0 ;

	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
	{
		pncb -> ncb_callname	[i] = ' ' ;
		pncb -> ncb_name	[i] = ' ' ;
	}
	pncb -> ncb_callname	[NCBNAMSZ - 1] = '\0' ;
	pncb -> ncb_name	[NCBNAMSZ - 1] = '\0' ;

	pncb -> ncb_rto		= 0 ;
	pncb -> ncb_sto		= 0 ;
	pncb -> ncb_post	= 0L ;
	pncb -> ncb_lana_num	= 0 ;
	pncb -> ncb_cmd_cplt	= 0 ;	
	for (i = 0 ; i < sncb_reserve ; ++i)
		pncb -> ncb_reserve [i]	= 0 ;
	pncb -> ncb_event       = 0L ;
}

/******************************************************************************

	Function:
		Initialize ADAPTER_STATUS Data Structure

	Parameters:
		PADAPTER_STATUS		pADAPTER_STATUS

	Returns:
		nothing

 *****************************************************************************/

void	ClearADAPTER_STATUS
(
	PADAPTER_STATUS		pADAPTER_STATUS
)
{
	int		i ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	for (i = 0 ; i < IEEE802_MAC_LENGTH ; ++i)
		pADAPTER_STATUS -> adapter_address [i] = 0 ;
	pADAPTER_STATUS -> rev_major         = 0 ;
	pADAPTER_STATUS -> reserved0         = 0 ;
	pADAPTER_STATUS -> adapter_type      = 0 ;
	pADAPTER_STATUS -> rev_minor         = 0 ;
	pADAPTER_STATUS -> duration          = 0 ;
	pADAPTER_STATUS -> frmr_recv         = 0 ;
	pADAPTER_STATUS -> frmr_xmit         = 0 ;

	pADAPTER_STATUS -> iframe_recv_err   = 0 ;

	pADAPTER_STATUS -> xmit_aborts       = 0 ;
	pADAPTER_STATUS -> xmit_success      = 0L ;
	pADAPTER_STATUS -> recv_success      = 0L ;

	pADAPTER_STATUS -> iframe_xmit_err   = 0 ;

	pADAPTER_STATUS -> recv_buff_unavail = 0 ;
	pADAPTER_STATUS -> t1_timeouts       = 0 ;
	pADAPTER_STATUS -> ti_timeouts       = 0 ;
	pADAPTER_STATUS -> reserved1         = 0L ;
	pADAPTER_STATUS -> free_ncbs         = 0 ;
	pADAPTER_STATUS -> max_cfg_ncbs      = 0 ;
	pADAPTER_STATUS -> max_ncbs          = 0 ;
	pADAPTER_STATUS -> xmit_buf_unavail  = 0 ;
	pADAPTER_STATUS -> max_dgram_size    = 0 ;
	pADAPTER_STATUS -> pending_sess      = 0 ;
	pADAPTER_STATUS -> max_cfg_sess      = 0 ;
	pADAPTER_STATUS -> max_sess          = 0 ;
	pADAPTER_STATUS -> max_sess_pkt_size = 0 ;
	pADAPTER_STATUS -> name_count        = 0 ;
}

/******************************************************************************

	Function:
		Initialize NAME_BUFFER Data Structure

	Parameters:
		PNAME_BUFFER 	pNAME_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	ClearNAME_BUFFER
(
	PNAME_BUFFER	pNAME_BUFFER
)
{
	int		i ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	for (i = 0 ; i < NCBNAMSZ - 1; ++i)
		pNAME_BUFFER -> name [i] = ' ' ;
	pNAME_BUFFER -> name [NCBNAMSZ - 1] = '\0' ;
	pNAME_BUFFER -> name_num = 0 ;
	pNAME_BUFFER -> name_flags = 0 ;
}

/******************************************************************************

	Function:
		Initialize SESSION_HEADER Data Structure

	Parameters:
		PSESSION_HEADER	pSESSION_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	ClearSESSION_HEADER
(
	PSESSION_HEADER		pSESSION_HEADER
)
{
	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pSESSION_HEADER -> sess_name = 0 ;
	pSESSION_HEADER -> num_sess = 0 ;
	pSESSION_HEADER -> rcv_dg_outstanding = 0 ;
	pSESSION_HEADER -> rcv_any_outstanding = 0 ;
}

/******************************************************************************

	Function:
		Initialize SESSION_BUFFER Data Structure

	Parameters:
		PSESSION_BUFFER	pSESSION_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	ClearSESSION_BUFFER
(
	PSESSION_BUFFER		pSESSION_BUFFER
)
{
	int		i ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pSESSION_BUFFER -> lsn = 0 ;
	pSESSION_BUFFER -> state = 0 ;
	for (i = 0 ; i < NCBNAMSZ - 1; ++i)
	{
		pSESSION_BUFFER -> local_name  [i] = ' ' ;
		pSESSION_BUFFER -> remote_name [i] = ' ' ;
	}
	pSESSION_BUFFER -> local_name  [NCBNAMSZ - 1] = '\0' ;
	pSESSION_BUFFER -> remote_name [NCBNAMSZ - 1] = '\0' ;
	pSESSION_BUFFER -> rcvs_outstanding = 0 ;
	pSESSION_BUFFER -> sends_outstanding = 0 ;
}

/******************************************************************************

	Function:
		Initialize LANA_ENUM Data Structure

	Parameters:
		PLANA_ENUM 	pLANA_ENUM

	Returns:
		nothing

 *****************************************************************************/

void	ClearLANA_ENUM
(
	PLANA_ENUM	pLANA_ENUM
)
{
	int		i ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pLANA_ENUM -> length = 0 ;
	for (i = 0 ; i <= MAX_LANA ; ++i)
		pLANA_ENUM -> lana [i] = 0 ;
}

/******************************************************************************

	Function:
		Initialize FIND_NAME_HEADER Data Structure

	Parameters:
		PFIND_NAME_HEADER 	pFIND_NAME_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	ClearFIND_NAME_HEADER
(
	PFIND_NAME_HEADER	pFIND_NAME_HEADER
)
{
	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pFIND_NAME_HEADER -> node_count   = 0 ;
	pFIND_NAME_HEADER -> reserved     = 0 ;
	pFIND_NAME_HEADER -> unique_group = 0 ;
}

/******************************************************************************

	Function:
		Initialize FIND_NAME_BUFFER Data Structure

	Parameters:
		PFIND_NAME_BUFFER 	pFIND_NAME_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	ClearFIND_NAME_BUFFER
(
	PFIND_NAME_BUFFER	pFIND_NAME_BUFFER
)
{
	int		i ;

	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pFIND_NAME_BUFFER -> length         = 0 ;
	pFIND_NAME_BUFFER -> access_control = 0 ;
	pFIND_NAME_BUFFER -> frame_control  = 0 ;
	for (i = 0 ; i < IEEE802_MAC_LENGTH ; ++i)
	{
		pFIND_NAME_BUFFER -> destination_addr [i] = 0 ;
		pFIND_NAME_BUFFER -> source_addr      [i] = 0 ;
	}
	for (i = 0 ; i < 18 ; ++i)
	{
		pFIND_NAME_BUFFER -> routing_info     [i] = 0 ;
	}
}

/******************************************************************************

	Function:
		Initialize ACTION_HEADER Data Structure

	Parameters:
		PACTION_HEADER 	pACTION_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	ClearACTION_HEADER
(
	PACTION_HEADER	pACTION_HEADER
)
{
	/**********************************************************************

		we initialize member by member to be safe (no memset tricks)

	 *********************************************************************/

	pACTION_HEADER -> transport_id = 0L ;
	pACTION_HEADER -> action_code  = 0 ;
	pACTION_HEADER -> reserved     = 0 ;
}
