/******************************************************************************
 *                                                                            *
 * File:   nbdump.c           Version  2.02            Date: 2010-04-03       *
 *                                                                            *
 * Copyright (C) 1998-2010 by Kostis Netzwerkberatung                         *
 * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056                        *
 * kosta@kostis.net (Konstantinos Kostis), http://www.kostis.net/             *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2010-04-03: KK V2.02                                                   *
 *        - see netbios.h                                                     *
 *                                                                            *
 *****************************************************************************/

#include <stdio.h>

#include "netbios.h"

/******************************************************************************

	Function:
		return MAC Address (6 Octets) as string

	Parameters:
		PUCHAR		pMAC
		char		*sMAC
		int		format

	Returns:
		nothing		(result in sMAC)

 *****************************************************************************/

void	StrMAC
(
	PUCHAR		pMAC,
	char		*sMAC,
	int		format
)
{
	char		*cFormat ;

	if (sMAC == (char *) NULL)
		return ;

	/**********************************************************************

		initialize strings (empty)

	 *********************************************************************/

	*sMAC = '\0' ;
	cFormat = (char *) NULL ;

	/**********************************************************************

		output depends on selected format

	 *********************************************************************/

	switch (format)
	{
		case	MAC_FORMAT_IEEE:

			cFormat = "%02X-%02X-%02X-%02X-%02X-%02X" ;
			break ;

		case	MAC_FORMAT_CISCO:

			cFormat = "%02x%02x.%02x%02x.%02x%02x" ;
			break ;

		case	MAC_FORMAT_COLON:

			cFormat = "%02x:%02x:%02x:%02x:%02x:%02x" ;
			break ;

		case	MAC_FORMAT_RAW:

			cFormat = "%02x%02x%02x%02x%02x%02x" ;
			break ;
	}

	if (cFormat != (char *) NULL)
	{
		sprintf (sMAC, cFormat,
			pMAC [0], pMAC [1], pMAC [2],
			pMAC [3], pMAC [4], pMAC [5]) ;
	}
}

/******************************************************************************

	Function:
		dump IEEE802 MAC Address (6 Octets)

	Parameters:
		PUCHAR		pMAC

	Returns:
		nothing

 *****************************************************************************/

void	DumpMAC
(
	PUCHAR		pMAC
)
{
	char		sMAC [MAC_MAX_STRLEN + 1] ;

	StrMAC (pMAC, sMAC, MAC_FORMAT_IEEE) ;

	printf ("%s\n", sMAC) ;
}

/******************************************************************************

	Function:
		dump byte using hex notation and blanks between them

	Parameters:
		PUCHAR		pBYTES

	Returns:
		nothing

 *****************************************************************************/

void	DumpBYTES
(
	PUCHAR		pBYTES,
	int		byte_count
)
{
	int		i ;

	for (i = 0 ; i < byte_count ; ++i)
	{
		printf ("%02X", pBYTES [i]) ;
		if (i < byte_count - 1)
			printf (" ") ;
	}

	printf ("\n") ;
}

/******************************************************************************

	Function:
		Dump NCB Data Structure

	Parameters:
		PNCB		pncb

	Returns:
		nothing

 *****************************************************************************/

void	DumpNCB
(
	PNCB		pncb
)
{
	int		i ;
	int		sncb_reserve = sizeof (pncb -> ncb_reserve) ;

	printf ("ncb_command         = 0x%02X\n", pncb -> ncb_command) ;
	printf ("ncb_retcode         = 0x%02X\n", pncb -> ncb_retcode) ;
	printf ("ncb_lsn             = 0x%02X\n", pncb -> ncb_lsn) ;
	printf ("ncb_num             = 0x%02X\n", pncb -> ncb_num) ;
	printf ("ncb_buffer          = 0x%08lX\n", pncb -> ncb_buffer) ;
	printf ("ncb_length          = 0x%04X\n", pncb -> ncb_length) ;
	printf ("ncb_callname        = \"") ;
	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
		printf ("%c", pncb -> ncb_callname [i]) ;
	printf ("\" 0x%02X\n",
		pncb -> ncb_callname [NCBNAMSZ - 1]) ;
	printf ("ncb_name            = \"") ;
	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
		printf ("%c", pncb -> ncb_name [i]) ;
	printf ("\" 0x%02X\n",
		pncb -> ncb_name [NCBNAMSZ - 1]) ;
	printf ("ncb_rto             = 0x%02X\n", pncb -> ncb_rto) ;
	printf ("ncb_sto             = 0x%02X\n", pncb -> ncb_sto) ;
	printf ("ncb_post            = 0x%08lX\n", pncb -> ncb_post) ;
	printf ("ncb_lana_num        = 0x%02X\n", pncb -> ncb_lana_num) ;
	printf ("ncb_cmd_cplt        = 0x%02X\n", pncb -> ncb_cmd_cplt) ;
	printf ("ncb_reserve         = ") ;
	DumpBYTES (pncb -> ncb_reserve, sncb_reserve) ;
	printf ("ncb_event           = 0x%08lX\n", pncb -> ncb_event) ;
}

/******************************************************************************

	Function:
		Dump ADAPTER_STATUS Data Structure

	Parameters:
		PADAPTER_STATUS	pADAPTER_STATUS

	Returns:
		nothing

 *****************************************************************************/

void	DumpADAPTER_STATUS
(
	PADAPTER_STATUS	pADAPTER_STATUS
)
{
	int		i ;

	printf ("adapter_address     = ") ;
	DumpMAC (pADAPTER_STATUS -> adapter_address) ;
	printf ("rev_major           = 0x%02X\n",
		pADAPTER_STATUS -> rev_major) ;
	printf ("reserved0           = 0x%02X\n",
		pADAPTER_STATUS -> reserved0) ;
	printf ("adapter_type        = 0x%02X\n",
		pADAPTER_STATUS -> adapter_type) ;
	printf ("rev_minor           = 0x%02X\n",
		pADAPTER_STATUS -> rev_minor) ;
	printf ("duration            = 0x%04X\n",
		pADAPTER_STATUS -> duration) ;
	printf ("frmr_recv           = 0x%04X\n",
		pADAPTER_STATUS -> frmr_recv) ;
	printf ("frmr_xmit           = 0x%04X\n",
		pADAPTER_STATUS -> frmr_xmit) ;
	printf ("iframe_recv_err     = 0x%04X\n",
		pADAPTER_STATUS -> iframe_recv_err) ;
	printf ("xmit_aborts         = 0x%04X\n",
		pADAPTER_STATUS -> xmit_aborts) ;
	printf ("xmit_success        = 0x%08lX\n",
		pADAPTER_STATUS -> xmit_success) ;
	printf ("recv_success        = 0x%08lX\n",
		pADAPTER_STATUS -> recv_success) ;
	printf ("iframe_xmit_err     = 0x%04X\n",
		pADAPTER_STATUS -> iframe_xmit_err) ;
	printf ("recv_buff_unavail   = 0x%04X\n",
		pADAPTER_STATUS -> recv_buff_unavail) ;
	printf ("t1_timeouts         = 0x%04X\n",
		pADAPTER_STATUS -> t1_timeouts) ;
	printf ("ti_timeouts         = 0x%04X\n",
		pADAPTER_STATUS -> ti_timeouts) ;
	printf ("reserved1           = 0x%08lX\n",
		pADAPTER_STATUS -> reserved1) ;
	printf ("free_ncbs           = 0x%04X\n",
		pADAPTER_STATUS -> free_ncbs) ;
	printf ("max_cfg_ncbs        = 0x%04X\n",
		pADAPTER_STATUS -> max_cfg_ncbs) ;
	printf ("max_ncbs            = 0x%04X\n",
		pADAPTER_STATUS -> max_ncbs) ;
	printf ("xmit_buf_unavail    = 0x%04X\n",
		pADAPTER_STATUS -> xmit_buf_unavail) ;
	printf ("max_dgram_size      = 0x%04X\n",
		pADAPTER_STATUS -> max_dgram_size) ;
	printf ("pending_sess        = 0x%04X\n",
		pADAPTER_STATUS -> pending_sess) ;
	printf ("max_sess            = 0x%04X\n",
		pADAPTER_STATUS -> max_sess) ;
	printf ("max_sess_pkt_size   = 0x%04X\n",
		pADAPTER_STATUS -> max_sess_pkt_size) ;
	printf ("name_count          = 0x%04X\n",
		pADAPTER_STATUS -> name_count) ;
}

/******************************************************************************

	Function:
		dump all from PADAPTER_NAMES Data Structure

	Parameters:
		PADAPTER_ALL	pADAPTER_ALL

	Returns:
		nothing

 *****************************************************************************/

void	DumpADAPTER_ALL
(
	PADAPTER_ALL	pADAPTER_ALL
)
{
	int		i ;
	int		name_count ;

	DumpADAPTER_STATUS (& pADAPTER_ALL -> adapter_status) ;
	name_count = pADAPTER_ALL -> adapter_status.name_count ;
	for (i = 0 ; i < name_count ; ++i)
		DumpNAME_BUFFER (& pADAPTER_ALL -> names [i]) ;
}

/******************************************************************************

	Function:
		dump NAME_BUFFER Data Structure

	Parameters:
		PNAME_BUFFER	pNAME_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	DumpNAME_BUFFER
(
	PNAME_BUFFER		pNAME_BUFFER
)
{
	int	i ;

	printf ("name                = \"") ;
	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
		printf ("%c", pNAME_BUFFER -> name [i]) ;
	printf ("\" 0x%02X\n",
		pNAME_BUFFER -> name [i]) ;
	printf ("name_num            = 0x%02X\n", pNAME_BUFFER -> name_num) ;
	printf ("name_flags          = 0x%02X\n", pNAME_BUFFER -> name_flags) ;
}

/******************************************************************************

	Function:
		dump SESSION_HEADER Data Structure

	Parameters:
		PSESSION_HEADER	pSESSION_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	DumpSESSION_HEADER
(
	PSESSION_HEADER	pSESSION_HEADER
)
{
	printf ("sess_name           = 0x%02X\n",
		pSESSION_HEADER -> sess_name) ;
	printf ("num_sess            = 0x%02X\n",
		pSESSION_HEADER -> num_sess) ;
	printf ("rcv_dg_outstanding  = 0x%02X\n",
		pSESSION_HEADER -> rcv_dg_outstanding) ;
	printf ("rcv_any_outstanding = 0x%02X\n",
		pSESSION_HEADER -> rcv_any_outstanding) ;
}

/******************************************************************************

	Function:
		dump SESSION_BUFFER Data Structure

	Parameters:
		PSESSION_BUFFER	pSESSION_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	DumpSESSION_BUFFER
(
	PSESSION_BUFFER	pSESSION_BUFFER
)
{
	int		i ;

	printf ("lsn                 = 0x%02X\n", pSESSION_BUFFER -> lsn) ;
	printf ("state               = 0x%02X\n", pSESSION_BUFFER -> state) ;

	printf ("local_name          = \"") ;
	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
		printf ("%c", pSESSION_BUFFER -> local_name [i]) ;
	printf ("\" 0x%02X\n",
		pSESSION_BUFFER -> local_name [NCBNAMSZ - 1]) ;
	printf ("remote_name         = \"") ;
	for (i = 0 ; i < NCBNAMSZ - 1 ; ++i)
		printf ("%c", pSESSION_BUFFER -> remote_name [i]) ;
	printf ("\" 0x%02X\n",
		pSESSION_BUFFER -> remote_name [NCBNAMSZ - 1]) ;

	printf ("rcvs_outstanding    = 0x%02X\n",
		pSESSION_BUFFER -> rcvs_outstanding) ;
	printf ("sends_outstanding   = 0x%02X\n",
		pSESSION_BUFFER -> sends_outstanding) ;
}

/******************************************************************************

	Function:
		dump all from PSESSION_ALL Data Structure

	Parameters:
		PSESSION_ALL	pSESSION_ALL

	Returns:
		nothing

 *****************************************************************************/

void	DumpSESSION_ALL
(
	PSESSION_ALL	pSESSION_ALL
)
{
	DumpSESSION_HEADER (& pSESSION_ALL -> session_header) ;
	DumpSESSION_BUFFER (& pSESSION_ALL -> session_buffer) ;
}

/******************************************************************************

	Function:
		dump FIND_NAME_HEADER Data Structure

	Parameters:
		PFIND_NAME_HEADER	pFIND_NAME_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	DumpFIND_NAME_HEADER
(
	PFIND_NAME_HEADER		pFIND_NAME_HEADER
)
{
	printf ("node_count          = 0x%04X\n",
		pFIND_NAME_HEADER -> node_count) ;
	printf ("reserved            = 0x%02X\n",
		pFIND_NAME_HEADER -> reserved) ;
	printf ("unique_group        = 0x%02X\n",
		pFIND_NAME_HEADER -> unique_group) ;
}

/******************************************************************************

	Function:
		dump FIND_NAME_BUFFER Data Structure

	Parameters:
		PFIND_NAME_BUFFER	pFIND_NAME_BUFFER

	Returns:
		nothing

 *****************************************************************************/

void	DumpFIND_NAME_BUFFER
(
	PFIND_NAME_BUFFER		pFIND_NAME_BUFFER
)
{
	printf ("length              = 0x%02X\n",
		pFIND_NAME_BUFFER -> length) ;
	printf ("access_control      = 0x%02X\n",
		pFIND_NAME_BUFFER -> access_control) ;
	printf ("frame_control       = 0x%02X\n",
		pFIND_NAME_BUFFER -> frame_control) ;
	printf ("destination_addr    = ") ;
	DumpMAC (pFIND_NAME_BUFFER -> destination_addr) ;
	printf ("source_addr         = ") ;
	DumpMAC (pFIND_NAME_BUFFER -> source_addr) ;
	printf ("routing_info        = ") ;
	DumpBYTES (pFIND_NAME_BUFFER -> routing_info, 18) ;
}

/******************************************************************************

	Function:
		dump all from PFIND_NAME_ALL Data Structure

	Parameters:
		PFIND_NAME_ALL	pFIND_NAME_ALL

	Returns:
		nothing

 *****************************************************************************/

void	DumpFIND_NAME_ALL
(
	PFIND_NAME_ALL	pFIND_NAME_ALL
)
{
	int		i ;
	int		node_count ;

	DumpFIND_NAME_HEADER (& pFIND_NAME_ALL -> fn_header) ;
	node_count = pFIND_NAME_ALL -> fn_header.node_count ;
	for (i = 0 ; i < node_count ; ++i)
		DumpFIND_NAME_BUFFER (& pFIND_NAME_ALL -> fn_buffer [i]) ;
}

/******************************************************************************

	Function:
		dump ACTION_HEADER Data Structure

	Parameters:
		PACTION_HEADER	pACTION_HEADER

	Returns:
		nothing

 *****************************************************************************/

void	DumpACTION_HEADER
(
	PACTION_HEADER		pACTION_HEADER
)
{
	printf ("transport_id        = 0x%08LX\n",
		pACTION_HEADER -> transport_id) ;
	printf ("action_code         = 0x%04X\n",
		pACTION_HEADER -> action_code) ;
	printf ("reserved            = 0x%04X\n",
		pACTION_HEADER -> reserved) ;
}
