/******************************************************************************
 *                                                                            *
 * File:   netbios.h          Version  2.02            Date: 2010-04-03       *
 *                                                                            *
 * Copyright (C) 1998-2010 by Kostis Netzwerkberatung                         *
 * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056                        *
 * kosta@kostis.net (Konstantinos Kostis), http://www.kostis.net/             *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *        - make nb30.h usable for MS-DOS Borland C++ 3.1 compiler and MS-DOS *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2010-04-03: KK V2.02                                                   *
 *        - corrected MAC_MAX_STRLEN and MAC_FORMAT_MAX_STRLEN                *
 *     2009-03-07: KK V2.01                                                   *
 *        - added MAC_FORMAT_DEFAULT                                          *
 *     2009-03-04: KK V2.00                                                   *
 *        - complete overhaul                                                 *
 *     2009-02-26: KK V1.02                                                   *
 *        - see nbdump.c                                                      *
 *     1998-05-04: KK V1.01                                                   *
 *        - see nbdump.c                                                      *
 *     1998-04-22: KK V1.00                                                   *
 *        - initial encoding                                                  *
 *                                                                            *
 *****************************************************************************/

/******************************************************************************

	Raw Data Types needed by nb30 if compiled for MS-DOS

 *****************************************************************************/

#ifndef	RAW_DATATYPES

	#define	RAW_DATATYPES

	typedef	unsigned char		UCHAR ;
	typedef unsigned char *		PUCHAR ;
	typedef	unsigned short int	WORD ;
	typedef	unsigned short int	USHORT ;
	typedef unsigned long int	DWORD ;
	typedef unsigned long int	ULONG ;
	typedef	unsigned long int	HANDLE ;
	#define				APIENTRY
	#define				CALLBACK	far

#endif

/******************************************************************************

	include WIN32 SDK file

 *****************************************************************************/

#include <nb30.h>

#ifndef	LANA_TYPE

	#define	LANA_TYPE

	typedef	struct _ADAPTER_ALL
	{
		ADAPTER_STATUS	adapter_status ;
		NAME_BUFFER	names	[MAX_LANA] ;
	} ADAPTER_ALL, *PADAPTER_ALL ;

	typedef struct _SESSION_ALL
	{
		SESSION_HEADER	session_header ;
		SESSION_BUFFER	session_buffer ;
	} SESSION_ALL, *PSESSION_ALL ;

	typedef	struct _FIND_NAME_ALL
	{
		FIND_NAME_HEADER	fn_header ;
		FIND_NAME_BUFFER	fn_buffer [MAX_LANA] ;
	} FIND_NAME_ALL, *PFIND_NAME_ALL ;
#endif

/******************************************************************************

	NetBIOS Constants

 *****************************************************************************/

#define	INT_NETBIOS_CALL	0x5C
#define	IEEE802_MAC_LENGTH	6

/******************************************************************************

	valid characters in NetBIOS names

 *****************************************************************************/

#define	NCB_VALID_CHARS		\
"!#$%&()'-.0123456789@ABCDEFGHIJKLMNOPQRSTUVWXYZ_^{}~"

/******************************************************************************

	NetBIOS Function Constants (Kostis Netzwerkberatung)

 *****************************************************************************/

#define	NBCHK_OK			0
#define	NBCHK_NAME_TOOLONG		1
#define	NBCHK_NAME_INVALID		2

/******************************************************************************

	NetBIOS Function Prototypes (Kostis Netzwerkberatung)

 *****************************************************************************/

extern	int	CheckNBName (char *NBName) ;

extern	void	ClearNCB (PNCB pncb) ;
extern	void	ClearADAPTER_STATUS (PADAPTER_STATUS pADAPTER_STATUS) ;
extern	void	ClearNAME_BUFFER (PNAME_BUFFER pNAME_BUFFER) ;
extern	void	ClearSESSION_HEADER (PSESSION_HEADER pSESSION_HEADER) ;
extern	void	ClearSESSION_BUFFER (PSESSION_BUFFER pSESSION_BUFFER) ;
extern	void	ClearLANA_ENUM (PLANA_ENUM pLANA_ENUM) ;
extern	void	ClearFIND_NAME_HEADER (PFIND_NAME_HEADER pFIND_NAME_HEADER) ;
extern	void	ClearFIND_NAME_BUFFER (PFIND_NAME_BUFFER pFIND_NAME_BUFFER) ;
extern	void	ClearACTION_HEADER (PACTION_HEADER pACTION_HEADER) ;

extern	void	DumpMAC (PUCHAR pMAC) ;
extern	void	DumpBYTES (PUCHAR pBYTES, int byte_count) ;
extern	void	DumpNCB (PNCB pncb) ;
extern	void	DumpADAPTER_STATUS (PADAPTER_STATUS pADAPTER_STATUS) ;
extern	void	DumpADAPTER_ALL (PADAPTER_ALL pADAPTER_ALL) ;
extern	void	DumpNAME_BUFFER (PNAME_BUFFER pNAME_BUFFER) ;
extern	void	DumpSESSION_HEADER (PSESSION_HEADER pSESSION_HEADER) ;
extern	void	DumpSESSION_BUFFER (PSESSION_BUFFER pSESSION_BUFFER) ;
extern	void	DumpSESSION_ALL (PSESSION_ALL pSESSION_ALL) ;
extern	void	DumpFIND_NAME_HEADER (PFIND_NAME_HEADER pFIND_NAME_HEADER) ;
extern	void	DumpFIND_NAME_BUFFER (PFIND_NAME_BUFFER pFIND_NAME_BUFFER) ;
extern	void	DumpFIND_NAME_ALL (PFIND_NAME_ALL pFIND_NAME_ALL) ;
extern	void	DumpACTION_HEADER (PACTION_HEADER pACTION_HEADER) ;

extern	void	StrMAC (PUCHAR pMAC, char *sMAC, int format) ;

/******************************************************************************

	NetBIOS Standard Function Prototype

 *****************************************************************************/

extern	UCHAR	Netbios (PNCB pncb) ;

/******************************************************************************

	MAC format constants (Kostis Netzwerkberatung)

 *****************************************************************************/

#define	MAC_FORMAT_DEFAULT	0	/* use application default format */

#define	MAC_FORMAT_IEEE		1	/* XX-XX-XX-XX-XX-XX */
#define MAC_FORMAT_CISCO	2	/* xxxx.xxxx.xxxx */
#define	MAC_FORMAT_COLON	3	/* xx:xx:xx:xx:xx:xx */
#define	MAC_FORMAT_RAW		4	/* xxxxxxxxxxxx */

#define MAC_MAX_STRLEN		17	/* XX-XX-XX-XX-XX-XX */
#define MAC_FORMAT_MAX_STRLEN	29	/* %02X-%02X-%02X-%02X-%02X-%02X */

#define	NETBIOS_LIB_VERSION	"2.02"
#define NETVIOS_LIB_DATE	"2010-04-03"
